#!/bin/sh

cd `dirname $0`

COLOR_RED=""
COLOR_GREEN=""
COLOR_OFF=""

font_color_type()
{
	COLOR_RED="\033[1;31m"
	COLOR_GREEN="\033[1;32m"
	COLOR_OFF="\033[m"
}

ARCHNAME=`uname -m`
case $ARCHNAME in
    x86_64)
		TELI_DIRNAME=$PWD/x64
		SO_PATH_FILE=telicamsdk_x64.conf
		font_color_type
		;;
    i*86)
		TELI_DIRNAME=$PWD/x86
		SO_PATH_FILE=telicamsdk_x86.conf
		font_color_type
		;;
    armv7l)
		TELI_DIRNAME=$PWD/armhf
		SO_PATH_FILE=telicamsdk_armhf.conf
		;;
    aarch64)
		TELI_DIRNAME=$PWD/aarch64
		SO_PATH_FILE=telicamsdk_aarch64.conf
		;;
    *)	
		echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] architecture not supported."
		exit 1
		;;
esac

OPT_TELICAMSDK=/opt/TeliCamSDK
HOME_DIR_TELICAMSDK=$HOME/TeliCamSDK
TELI_RULE_FILE=80-telicamsdk.rules
RULE_DIR=/etc/udev/rules.d
TELICAMVIEWER_LAUNCHER=/usr/share/applications/telicamlinuxviewer.desktop
TELICAMVIEWER_LAUNCHER_USER_LOCAL=$HOME/.local/share/applications/telicamlinuxviewer.desktop
TELI_IPCONFIGRATIONTOOL_LAUNCHER=/usr/share/applications/teliipconfigrationtool.desktop
TELI_IPCONFIGRATIONTOOL_LAUNCHER_USER_LOCAL=$HOME/.local/share/applications/IpConfigurationToolLinux.desktop
ROOT_TELICAMSDK=/root/TeliCamSDK

echo ""

read -p "Do you want to remove TeliCamSDK?[y/n]:" RemoveYesNo

case $RemoveYesNo in
[Yy]*)
	SUDO=""
	if [ `id -u` != "0" ] ; then
	    SUDO="sudo"
	fi

	ECHOOP=""
	if [ -e /etc/redhat-release ] ; then
		GETDISTRIB=`cat /etc/redhat-release | awk 'NR == 1 {print $1}'`
	else
		GETDISTRIB=`cat /etc/issue | awk 'NR == 1 {print $1}'`
	fi

	case $GETDISTRIB in
	Ubuntu)
		;;
	Debian)
		;;
	Fedora)
		ECHOOP="-e"
		;;
	CentOS)
		ECHOOP="-e"
		;;
	*)
		;;
	esac

	echo ""

	echo "Removing TeliCamSDK samples."
	if [ -e "$HOME_DIR_TELICAMSDK" ] ; then
		$SUDO rm -rf "$HOME_DIR_TELICAMSDK"
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 2"
			exit 2
		fi

		echo $ECHOOP "[$COLOR_GREEN OK $COLOR_OFF] samples."
	else 
		echo "Not exist."
	fi

	echo ""

	if [ -e "$TELICAMVIEWER_LAUNCHER" ] ; then 
		$SUDO rm -rf $TELICAMVIEWER_LAUNCHER
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 10"
			exit 10
		fi
	fi

	if [ -e "$TELICAMVIEWER_LAUNCHER_USER_LOCAL" ] ; then 
		$SUDO rm -rf $TELICAMVIEWER_LAUNCHER_USER_LOCAL
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 20"
			exit 20
		fi
	fi

	if [ -e "$TELI_IPCONFIGRATIONTOOL_LAUNCHER" ] ; then
		$SUDO rm -rf $TELI_IPCONFIGRATIONTOOL_LAUNCHER
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_ERROR_RED ERROR $COLOR_OFF] exit code 30"
			exit 30
		fi
	fi

	if [ -e "$TELI_IPCONFIGRATIONTOOL_LAUNCHER_USER_LOCAL" ] ; then
		$SUDO rm -rf $TELI_IPCONFIGRATIONTOOL_LAUNCHER_USER_LOCAL
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_ERROR_RED ERROR $COLOR_OFF] exit code 40"
			exit 40
		fi
	fi

	if [ -e "$RULE_DIR/$TELI_RULE_FILE" ] ; then 
		$SUDO rm -rf $RULE_DIR/$TELI_RULE_FILE
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 50"
			exit 50
		fi
	fi

	echo ""

	echo "Removing TeliCamSDK api."
	if [ -e "$OPT_TELICAMSDK" ] ; then

		if [ `id -u` != "0" ] ; then
			$SUDO rm -rf $ROOT_TELICAMSDK
			if [ $? != 0 ] ; then
				echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 60"
				exit 60
			fi
		fi

		if [ -e /etc/profile.d/telicamsdk.sh ] ; then
			$SUDO rm -rf /etc/profile.d/telicamsdk.sh
			if [ $? != 0 ] ; then
				echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 70"
				exit 70
			fi
		fi



		if [ -e /etc/ld.so.conf.d/"$SO_PATH_FILE" ] ; then
			$SUDO rm -rf /etc/ld.so.conf.d/$SO_PATH_FILE
			if [ $? != 0 ] ; then
				echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 80"
				exit 80
			fi
		fi

		$SUDO ldconfig

		$SUDO rm -rf $OPT_TELICAMSDK
		if [ $? != 0 ] ; then
			echo $ECHOOP "[$COLOR_RED ERROR $COLOR_OFF] exit code 90"
			exit 90
		fi

		echo $ECHOOP "[$COLOR_GREEN OK $COLOR_OFF] api."
	else 
		echo "Not exist."
	fi

	echo "TeliCamSDK was successfully removed from your computer."
	echo ""
	;;
[Nn]*) 
	echo "Exit."
	;;
*) 
	echo "Exit."
	echo "Please Select.('y' or 'n')"
	;;
esac